<?php

//phpgw::import_class('phpgwapi.datetime');  // just a test import

	/*
 * parent SO object defining table names
 */
	interface sobim
	{
	 
	const bimItemTable = 'fm_bim_item';
	const bimTypeTable = 'fm_bim_type';
	const bimModelTable = 'fm_bim_model';

	}